@@ -37,7 +37,7 @@ public:
 
   bool isSoundEnabled() const override;
 
-  void changeGameboard(const QString &gameboard) override;
+  void changeGameboard(const QString &gameboard) override final;
 
 protected:
   void readOptions(QString &board, QString &language);
@@ -57,8 +57,6 @@ private slots:
   void editCopy();
   void soundOff();
   void changeGameboardFromCombo(int index);
-  void changeGameboard();
-  void changeLanguage();
   void toggleFullScreen();
   void lockAspectRatio(bool lock);
 
